searchData={"items":[{"type":"module","title":"TelemetryMetricsMnesia","doc":"`Telemetry.Metrics` reporter and metrics backend based on Mnesia DB.","ref":"TelemetryMetricsMnesia.html"},{"type":"module","title":"Installation - TelemetryMetricsMnesia","doc":"Just add the reporter to your dependencies in `mix.exs`:\n\n    defp deps do\n      [\n        {:telemetry_metrics_mnesia, \"~> 0.1.0\"}\n      ]\n    end","ref":"TelemetryMetricsMnesia.html#module-installation"},{"type":"module","title":"Configuration - TelemetryMetricsMnesia","doc":"You can configure optional cleanup process. Add the following to your `config.exs`:\n\n```elixir\nimport Config\n\nconfig :telemetry_metrics_mnesia,\n  # Timeout between cleanup process invocations in seconds, default 10.\n  cleanup_timeout: 10,\n\n  # Max telemetry events age to store in seconds (0 means infinity), default 0.\n  max_storage_time: 5\n```\n\nWhen `max_storage_time` is zero cleanup process doesn't start.","ref":"TelemetryMetricsMnesia.html#module-configuration"},{"type":"module","title":"Starting - TelemetryMetricsMnesia","doc":"To use it, start the reporter with the `start_link/1` function, providing it a list of\n`Telemetry.Metrics` metric definitions:\n\n \n\n#","ref":"TelemetryMetricsMnesia.html#module-starting"},{"type":"module","title":"From code - TelemetryMetricsMnesia","doc":"```elixir\nimport Telemetry.Metrics\n\nTelemetryMetricsMnesia.start_link(\n  metrics: [\n    counter(\"http.request.count\"),\n    sum(\"http.request.payload_size\"),\n    last_value(\"vm.memory.total\")\n  ]\n)\n```\n\n#","ref":"TelemetryMetricsMnesia.html#module-from-code"},{"type":"module","title":"From supervisor - TelemetryMetricsMnesia","doc":"```elixir\n import Telemetry.Metrics\n\n children = [\n  {TelemetryMetricsMnesia, [\n    metrics: [\n      counter(\"http.request.count\"),\n      sum(\"http.request.payload_size\"),\n      last_value(\"vm.memory.total\")\n    ]\n  ]}\n]\n\nSupervisor.start_link(children, ...)\n```\n\n \n\nThere are a couple `reporter_options` you can use:\n- `granularity: [unit: amount]` - sets metric calculation timespan. By default, infinity (it uses all available data).","ref":"TelemetryMetricsMnesia.html#module-from-supervisor"},{"type":"module","title":"How metrics are stored - TelemetryMetricsMnesia","doc":"By default, raw events with timestamps are stored in `memory_only` tables in Mnesia DB without distribution.\n\nThese options are going to be implemented soon...","ref":"TelemetryMetricsMnesia.html#module-how-metrics-are-stored"},{"type":"module","title":"How metrics are returned - TelemetryMetricsMnesia","doc":"#","ref":"TelemetryMetricsMnesia.html#module-how-metrics-are-returned"},{"type":"module","title":"Single metric - TelemetryMetricsMnesia","doc":"A `Map` with a metric type key. You can specify exact metric type to get value only.\n\n#### `Counter`\n\n```elixir\n%{Telemetry.Metrics.Counter => 2} = TelemetryMetricsMnesia.fetch([:some, :metric])\n 2 = TelemetryMetricsMnesia.fetch([:some, :metric], type: Telemetry.Metrics.Counter)\n```\n\n#### `Sum`\n\n```elixir\n%{Telemetry.Metrics.Sum => 4} = TelemetryMetricsMnesia.fetch([:some, :metric])\n 4 = TelemetryMetricsMnesia.fetch([:some, :metric], type: Telemetry.Metrics.Sum)\n```\n\n#### `LastValue`\n\n```elixir\n%{Telemetry.Metrics.LastValue => 8} = TelemetryMetricsMnesia.fetch([:some, :metric])\n 8 = TelemetryMetricsMnesia.fetch([:some, :metric], type: Telemetry.Metrics.LastValue)\n```\n\n#### `Distribution`\n\n```elixir\n%{Telemetry.Metrics.Distribution => %{\n    median: 5,\n    p75: 6,\n    p90: 6.5,\n    p95: 6.6,\n    p99: 6.6\n  }\n} = TelemetryMetricsMnesia.fetch([:some, :metric])\n\n%{\n  median: 5,\n  p75: 6,\n  p90: 6.5,\n  p95: 6.6,\n  p99: 6.6\n} = TelemetryMetricsMnesia.fetch([:some, :metric], type: Telemetry.Metrics.Distribution)\n```\n\n#### `Summary`\n\n```elixir\n %{Telemetry.Metrics.Summary => %{\n     mean: 5,\n     median: 6,\n     variance: 1,\n     standard_diviation: 0.5,\n     count: 100\n    }\n  } = TelemetryMetricsMnesia.fetch([:some, :metric])\n\n %{\n   mean: 5,\n   median: 6,\n   variance: 1,\n   standard_diviation: 0.5,\n   count: 100\n  } = TelemetryMetricsMnesia.fetch([:some, :metric], type: Telemetry.Metrics.Summary)\n```\n\n#","ref":"TelemetryMetricsMnesia.html#module-single-metric"},{"type":"module","title":"Several metric types at once - TelemetryMetricsMnesia","doc":"A `Map` with several metric type keys will be returned.\n\n```elixir\n%{\n  Telemetry.Metrics.Distribution => %{\n    median: 4,\n    p75: 5,\n    p90: 7,\n    p95: 7,\n    p99: 8\n  },\n  Telemetry.Metrics.Summary => %{\n    mean: 5,\n    variance: 1,\n    standard_deviation: 0.5,\n    median: 5,\n    count: 100\n  }\n} = TelemetryMetricsMnesia.fetch([:some, :metric])\n```\n\n#","ref":"TelemetryMetricsMnesia.html#module-several-metric-types-at-once"},{"type":"module","title":"Metric with tags - TelemetryMetricsMnesia","doc":"A nested `Map` with metric type keys at the first level and maps with tags vs values at the second.\n```elixir\n%{\n  Telemetry.Metrics.Counter => %{\n    %{endpoint: \"/\", code: 200} => 10,\n    %{endpoint: \"/\", code: 500} => 100,\n    %{endpoint: \"/api\", code: 200} => 500\n  }\n} = TelemetryMetricsMnesia.fetch([:some, :metric])\n\n%{\n  %{endpoint: \"/\", code: 200} => 10,\n  %{endpoint: \"/\", code: 500} => 100,\n  %{endpoint: \"/api\", code: 200} => 500\n} = TelemetryMetricsMnesia.fetch([:some, :metric], type: Telemetry.Metrics.Counter)\n```","ref":"TelemetryMetricsMnesia.html#module-metric-with-tags"},{"type":"function","title":"TelemetryMetricsMnesia.child_spec/1","doc":"","ref":"TelemetryMetricsMnesia.html#child_spec/1"},{"type":"function","title":"TelemetryMetricsMnesia.fetch/2","doc":"Retrieves metric data by its name. Returns a map.\n\n`opts` are:\n - `type` allows to get raw metric data for exact Telemetry.Metrics type module.\n\nMore info in [\"How metrics are returned\"](#module-how-metrics-are-returned).","ref":"TelemetryMetricsMnesia.html#fetch/2"},{"type":"function","title":"TelemetryMetricsMnesia.start_link/1","doc":"Starts a reporter and links it to the process.\n\nAvailable options:\n- `:metrics` - Required. List of metrics to handle.\n- `:mnesia` - Optional. Mnesia settings for distribution.\n  - `:distributed` - Optional. Boolean. If distribution enabled. Default, `true`.\n  - `:node_discovery` - Optional. Boolean. If node discovery process is needed. Default, `true`.\n\nMore examples in [\"Starting\"](#module-starting) and [\"How metrics are stored\"](#module-how-metrics-are-stored).","ref":"TelemetryMetricsMnesia.html#start_link/1"},{"type":"type","title":"TelemetryMetricsMnesia.distribution/0","doc":"","ref":"TelemetryMetricsMnesia.html#t:distribution/0"},{"type":"type","title":"TelemetryMetricsMnesia.metric_data/0","doc":"See [\"How metrics are returned\"](#module-how-metrics-are-returned)","ref":"TelemetryMetricsMnesia.html#t:metric_data/0"},{"type":"type","title":"TelemetryMetricsMnesia.option/0","doc":"","ref":"TelemetryMetricsMnesia.html#t:option/0"},{"type":"type","title":"TelemetryMetricsMnesia.options/0","doc":"","ref":"TelemetryMetricsMnesia.html#t:options/0"},{"type":"type","title":"TelemetryMetricsMnesia.summary/0","doc":"","ref":"TelemetryMetricsMnesia.html#t:summary/0"},{"type":"type","title":"TelemetryMetricsMnesia.tagged_metrics/1","doc":"","ref":"TelemetryMetricsMnesia.html#t:tagged_metrics/1"}],"content_type":"text/markdown"}